"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const GlobalConfigProcessor_1 = require("../universal/GlobalConfigProcessor");
const LoggerBroker_1 = require("../universal/LoggerBroker");
class DaemonIntrospection {
    constructor(daemon) {
        this.globalProperties = GlobalConfigProcessor_1.GlobalConfigProcessor.getInstance().getAllProperties();
        this.daemon = daemon;
    }
    async listApplication() {
        const daemon = this.daemon;
        const keySet = Array.from(daemon.apps.keys());
        const ret = [];
        for (const key of keySet) {
            const complex = daemon.apps.get(key);
            const introspection = await complexToIntrospection(complex);
            ret.push(introspection);
        }
        return ret;
    }
    async getApplictaionByName(appName) {
        const daemon = this.daemon;
        const complex = daemon.apps.get(appName);
        if (!complex) {
            throw new Error(`Can\'t found an Application it named ${appName}`);
        }
        return complexToIntrospection(complex);
    }
    getLoadedGlobalConfigPaths() {
        return GlobalConfigProcessor_1.GlobalConfigProcessor.getInstance().loadedConfigPath;
    }
    getLoadedEndPointNames() {
        let loadedEndPoints = [];
        for (let endPointName in this.globalProperties['actuator']['endPoint']) {
            if (this.globalProperties['actuator']['endPoint'][endPointName].enabled) {
                loadedEndPoints.push(endPointName);
            }
        }
        return loadedEndPoints;
    }
    getLoadedReporterNames() {
        let loadedReporters = [];
        for (let reporterName in this.globalProperties['reporter']) {
            if (this.globalProperties['reporter'][reporterName].enabled) {
                loadedReporters.push(reporterName);
            }
        }
        return loadedReporters;
    }
    introspectDaemon() {
        return {
            versions: Object.assign({}, process.versions, { pandora: require('../../package.json').version }),
            cwd: process.cwd(),
            pid: process.pid,
            uptime: process.uptime(),
            loadedGlobalConfigPaths: this.getLoadedGlobalConfigPaths(),
            loadedEndPoints: this.getLoadedEndPointNames(),
            loadedReporters: this.getLoadedReporterNames(),
        };
    }
}
exports.DaemonIntrospection = DaemonIntrospection;
async function complexToIntrospection(complex) {
    return {
        state: complex.state,
        mode: complex.mode,
        appName: complex.name,
        appDir: complex.appDir,
        appId: complex.appId,
        pids: complex.pids,
        uptime: complex.uptime,
        startCount: complex.startCount,
        representation: complex.appRepresentation,
        complex: await complex.getComplex(),
        stdoutLogPath: LoggerBroker_1.getAppLogPath(complex.name, 'nodejs_stdout')
    };
}
//# sourceMappingURL=DaemonIntrospection.js.map